@@ -1,5 +1,6 @@
 /*
- * LALXMLVCSInfo.h - LALXML VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALXMLVCSInfo.h - LALXML VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALXML_NAME "LALXML"
-#define LALXML_VCS_ID "5dccdb192921334191a1fbb2a6b9ee57d7b9d522"
-#define LALXML_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALXML_VCS_ID "5fd4ddfcd98132791ae58e05ca8e2ec0322bd47a"
+#define LALXML_VCS_DATE "2017-02-6 18:15:58 +0000"
 #define LALXML_VCS_BRANCH "None"
-#define LALXML_VCS_TAG "lalxml-v1.2.3"
+#define LALXML_VCS_TAG "lalxml-v1.2.4"
 #define LALXML_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALXML_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALXML_VCS_CLEAN "CLEAN"
 #define LALXML_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALXML_VCS_IDENT_ID "$" "LALXMLId: 5dccdb192921334191a1fbb2a6b9ee57d7b9d522 " "$"
-#define LALXML_VCS_IDENT_DATE "$" "LALXMLDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALXML_VCS_IDENT_BRANCH "$" "LALXMLBranch: None " "$"
-#define LALXML_VCS_IDENT_TAG "$" "LALXMLTag: lalxml-v1.2.3 " "$"
-#define LALXML_VCS_IDENT_AUTHOR "$" "LALXMLAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALXML_VCS_IDENT_COMMITTER "$" "LALXMLCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALXML_VCS_IDENT_STATUS "$" "LALXMLStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalXMLVCSInfoHeader = { \
-  LALXML_NAME, \
-  LALXML_VERSION, \
-  LALXML_VCS_ID, \
-  LALXML_VCS_DATE, \
-  LALXML_VCS_BRANCH, \
-  LALXML_VCS_TAG, \
-  LALXML_VCS_AUTHOR, \
-  LALXML_VCS_COMMITTER, \
-  LALXML_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALXML_VCS_LINK_CHECK LALXML_CLEAN_5fd4ddfcd98132791ae58e05ca8e2ec0322bd47a_VCS_HEADER_LIBRARY_MISMATCH
+void LALXML_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalXMLVCSInfoHeader = { \
 #endif /* _LALXMLVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
